@@ -26,3 +26,13 @@ drop_units.quantities <- function(x) {
 #' @name drop_quantities
 #' @export
 drop_errors.quantities <- drop_units.quantities
+
+#' @name drop_quantities
+#' @export
+drop_quantities.data.frame <- function(x) {
+  for (i in seq_along(x)) {
+    if (inherits(x[[i]], "quantities"))
+      x[[i]] <- drop_quantities(x[[i]])
+  }
+  x
+}
